# Default options: --with sound --with dlopen --with xscreensaver
#
# --without sound:  disables all sound support.
# --without dlopen: links with OpenAL and libvorbisfile at compile-time,
#                   rather than deferring it to run-time.
# --without xscreensaver:
#                   produce stand-alone programs only.
#
# This spec file can only be used with a modular, configurable XScreenSaver,
# which is pretty much only Fedora at the moment.

%{?_with_sound: %{?_without_sound:%{error:both '--with sound' and '--without sound' specified}}}
%{?_with_dlopen:%{?_without_sound:%{error:both '--with dlopen' and '--without dlopen' specified}}}
%{?_with_xscreensaver:%{?_without_xscreensaver:%{error:both '--with xscreensaver' and '--without xscreensaver' specified}}}

%{?_without_sound: %define _configure_sound --disable-sound}
%{!?_without_sound:%define _configure_sound --enable-sound%{!?_without_dlopen:=dlopen}}

# Sanity check: don't allow --with xscreensaver if xscreensaver wasn't
# around when rsxs.spec was generated by configure, because we really don't
# know where files are supposed to go...
%if 0%{!?_without_xscreensaver:1}
	%if "yes" != "yes" || "yes" != "yes" || "yes" != "yes"
		%{error:spec file was not generated by ./configure --with-xscreensaver --with-moduledir --with-configdir}
	%else
		%define _use_xscreensaver 1
	%endif
%endif

%if 0%{?_use_xscreensaver}

	# Expand hackdir -- configure leaves this unexpanded so that
	# one could do "make install exec_prefix=..."
	%define _hackdir %(exec_prefix="%{_exec_prefix}"; echo "/usr/libexec/xscreensaver")

	%define _moduledir /usr/share/xscreensaver/hacks.conf.d
	%define _configdir /usr/share/xscreensaver/config
	%define __xscreensaver_command /usr/bin/xscreensaver-command
	%define __xscreensaver_updater /usr/sbin/update-xscreensaver-hacks

	%define _configure_xscreensaver --with-xscreensaver --with-hackdir=%{_hackdir} --with-moduledir=%{_moduledir} --with-xscreensaver-updater=%{__xscreensaver_updater} --without-defaultdir --with-configdir=%{_configdir}

%else

	# Always use bindir here
	%define _hackdir %(exec_prefix="%{_exec_prefix}"; echo "${exec_prefix}/bin")

	%define _configure_xscreensaver --without-xscreensaver

%endif

%define _configure_opts %{_configure_sound} %{_configure_xscreensaver} --enable-image

Name: rsxs
Version: 1.0
Release: 1%{?dist}
License: GPL
Source0: rsxs-1.0.tar.gz
URL: http://rsxs.sourceforge.net/
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires: libSM-devel, libICE-devel, libXmu-devel, libXt-devel
BuildRequires: libGL-devel, libGLU-devel, libpng-devel
%{!?_without_sound:BuildRequires: openal-devel, libvorbis-devel}
Summary: Really Slick XScreenSavers
Group: Amusements/Graphics
%{?_use_xscreensaver:Requires: xscreensaver-base, xscreensaver-gl-base}
%{?_use_xscreensaver:Requires(post):   %{__xscreensaver_updater}}
%{?_use_xscreensaver:Requires(postun): %{__xscreensaver_updater}}
Obsoletes: rsxs-nosound
Provides: rsxs-nosound

%description
The Really Slick XScreenSavers package is an X11/GLX port of the
Really Slick Screensavers collection, by Terry Welsh
(http://www.reallyslick.com).

%prep
%setup -q -n rsxs-1.0

%build
%{configure} %{_configure_opts}
%{__make}

%install
if test "$RPM_BUILD_ROOT" != "/"; then
	%{__rm} -rf $RPM_BUILD_ROOT
fi
%{makeinstall} \
	hackdir=$RPM_BUILD_ROOT%{_hackdir} \
	moduledir=$RPM_BUILD_ROOT%{_moduledir} \
	configdir=$RPM_BUILD_ROOT%{_configdir}

%clean
if test "$RPM_BUILD_ROOT" != "/"; then
	%{__rm} -rf $RPM_BUILD_ROOT
fi

%if 0%{?_use_xscreensaver}

%post
%{__xscreensaver_updater}
if %{__xscreensaver_command} -version &> /dev/null; then
	%{__xscreensaver_command} --restart &> /dev/null || :
fi

%postun
if test $1 -eq 0; then
	%{__xscreensaver_updater}
	if %{__xscreensaver_command} -version &> /dev/null; then
		%{__xscreensaver_command} --restart &> /dev/null || :
	fi
fi

%endif

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog INSTALL README THANKS
%{_hackdir}/rs-*
%if 0%{?_use_xscreensaver}
%{_configdir}/rs-*
%{_moduledir}/rs-*
%endif
%{_datadir}/rsxs

%changelog
* Fri Nov 21 2008 Michael Chapman <foonly@users.sourceforge.net> 1.0-1
- bump license to GPLv3
- another package overhaul, for even more modern OSs
- moved hack config into separate files, to be compatible with "modular"
  XScreenSaver configurations (eg, Fedora)
- fixed skyrocket window reshape handler
- attempt to maximize or use "real" fullscreen mode with --fullscreen option

* Sat Jul 15 2005 Michael Chapman <foonly@users.sourceforge.net> 0.9-1
- fixed skyrocket memory allocation
- fixed xscreensaver config files
- added hyperspace screensaver
- package overhaul; it now actually builds on modern OSs!
- added libltdl so sound can be dynamically loaded; this simplifies
  the RPM packaging considerably

* Fri Jul 11 2003 Michael Chapman <foonly@users.sourceforge.net> 0.8-1
- major package restructure
- added skyrocket screensaver

* Wed Dec 11 2002 Michael Chapman <foonly@users.sourceforge.net> 0.7-1
- added flocks screensaver
- added flux screensaver
- added solarwinds screensaver
- cleaned up command-line argument handling
- added support for pre-4.0 versions of xscreensaver

* Sat Dec 07 2002 Michael Chapman <foonly@users.sourceforge.net> 0.6-1
- added lattice screensaver
- converted textures to PNG format
- small Makefile fix to build correctly on Gentoo

* Tue Nov 28 2002 Michael Chapman <foonly@users.sourceforge.net> 0.5-1
- added euphoria screensaver
- fixed bug in timing delay
- removed unnecessary #include <ios>

* Tue Nov 27 2002 Michael Chapman <foonly@users.sourceforge.net> 0.4-2
- fixed uninstall script -- should upgrade properly now
- fixed bug in timing delay

* Tue Nov 26 2002 Michael Chapman <mchapman@student.usyd.edu.au> 0.4-1
- added helios screensaver
- expanded screensaver descriptions
- removed unnecessary labels

* Mon Nov 19 2002 Michael Chapman <mchapman@student.usyd.edu.au> 0.3-1
- added fieldlines screensaver
- fixed bug in this changelog (!)
- fixed bug in uninstall and verify scripts

* Mon Nov 18 2002 Michael Chapman <mchapman@student.usyd.edu.au> 0.2-1
- added cyclone screensaver

* Tue Nov 12 2002 Michael Chapman <mchapman@student.usyd.edu.au> 0.1-1
- initial version
